"""POO Test plugin app for Alliance Auth."""

# pylint: disable = invalid-name
default_app_config = "pootest.apps.PootestConfig"

__version__ = "0.11.0"

__app_name_verbose__ = "AA POO Test"
__git_repo_url__ = "https://github.com/PooAmped/aa-pootest"

# ESI compatibility date — pins the ESI OpenAPI spec version used by the client.
# See https://esi.evetech.net/meta/compatibility-dates
__esi_compatibility_date__ = "2025-12-16"
