{% extends 'pootest/base.html' %}
{% load i18n %}
{% load humanize %}

{% block content %}

<div class="card card-default card-tabs">
    <div class="card-body">
        <h5 class="card-title">Welcome</h5>
        <p class="card-text">{{ text }}</p>
        <a href="{% url 'pootest:structures' %}" class="btn btn-primary">
            View Corporation Structures
        </a>
    </div>
</div>

{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
