"""App settings."""

from django.conf import settings

# Example optional setting. Override in your AA `settings/local.py` if needed.
POOTEST_SETTING_ONE = getattr(settings, "POOTEST_SETTING_ONE", None)
