"""Routes."""

from django.urls import path

from . import views

app_name = "pootest"

urlpatterns = [
    path("", views.index, name="index"),
    path("structures/", views.structures, name="structures"),
]
