"""Shared ESI client for aa-pootest.

Uses the modern django-esi (>=9.4) OpenAPI client, the same one used by current
Alliance Auth 5 apps (e.g. memberaudit, corp-tools, miningtaxes).
"""

from esi.openapi_clients import ESIClientProvider

from . import (
    __app_name_verbose__,
    __esi_compatibility_date__,
    __git_repo_url__,
    __version__,
)

esi = ESIClientProvider(
    compatibility_date=__esi_compatibility_date__,
    ua_appname=__app_name_verbose__,
    ua_version=__version__,
    ua_url=__git_repo_url__,
    operations=[
        "GetCharactersCharacterId",
        "GetCorporationsCorporationIdStructures",
        "GetCorporationsCorporationIdAssets",
        "GetUniverseStructuresStructureId",
        "GetUniverseSystemsSystemId",
        "GetUniverseTypesTypeId",
    ],
)
