{% extends 'allianceauth/base-bs5.html' %}
{% load humanize %}
{% load i18n %}

{% block page_title %}POO Test{% endblock %}

{% block header_nav_brand %}POO Test{% endblock %}

{% block header_nav_user_character_control %}
    {% comment %}
        Leave empty to remove user control nav items for this app
    {% endcomment %}
{% endblock %}

{% block content %}{% endblock %}
